# this script creates this example dataset:
# logistic regression - 02_logistic.csv

library(dplyr)
library(faux)

# data setup
set.seed(123)
n <- 1000
dat <-
  rnorm_multi(n = n,
              r = .5,
              varnames = paste0("x", 1:2)) |> 
  mutate(y = rbinom(n = n, 
                    size = 1, 
                    prob = pnorm(scale(x1 + x2 + x1*x2 + rnorm(n)))))

# fit model to complete data
mod1 <- glm(y ~ x1*x2, dat, family = binomial)
summary(mod1)

# make data missing
dat <-
  dat |> 
  mutate(
    # x2: MAR, conditional on x1
    x2 = ifelse((x1 > quantile(x1, .7)) & (runif(n) > .3), NA, x2)
    ) 

# fit model with casewise deletion
mod2 <- glm(y ~ x1*x2, dat, family = binomial)
summary(mod2)

# write.csv(dat, "02_logistic.csv", row.names = F, na = "-999")
