# this script creates this example dataset:
# mediation - 03_mediation.csv

library(dplyr)
library(faux)
library(lavaan)

# data setup
set.seed(123)
n <- 100
dat <-
  rnorm_multi(n = n,
              r = sample(c(.4, .5, .6), 10, replace = T),
              varnames = paste0("x", 1:5))

mod <- cfa("x =~ x1 + x2 + x3 + x4 + x5", dat)
x <- lavPredict(mod)[,1] # get factor scores to calculate m and y

dat <- 
  dat |> 
  mutate(m = x + rnorm(n),
         y = m + x + rnorm(n))

# fit model to complete data
syntax <- "
x =~ x1 + x2 + x3 + x4 + x5
m ~ a*x
y ~ c*x + b*m
ab := a*b
total := c + (a*b)
"
mod1 <- sem(syntax, dat)
summary(mod1)

# make data missing
dat <-
  dat |> 
  mutate(
    # m: MAR, conditional on x
    m = ifelse((x > quantile(x, .3)) & (runif(n) > .7), NA, m)
    )

# fit model with casewise deletion
mod2 <- sem(syntax, dat)
summary(mod2)

# write.csv(dat, "03_mediation.csv", row.names = F)
