# this script creates this example dataset:
# multilevel - 04_multilevel.csv

library(dplyr)
library(tidyr)
library(faux)
library(lme4)

# data setup
set.seed(123)
n1 <- 20
n2 <- 30
dat <-
  rnorm_multi(n = n2,
              mu = 0:1,
              sd = .5,
              r = .5,
              varnames = paste0("u", 0:1, "j")) |> 
  mutate(j = 1:n2,
         n1 = n1) |> 
  uncount(n1) |> 
  bind_cols(rnorm_multi(n = n1*n2,
                        r = .4,
                        varnames = paste0("x", 1:3, "i"))) |> 
  mutate(y = u0j + u1j*x1i + x2i + x3i + x2i * x3i + rnorm(n1*n2))

# fit model to complete data
mod1 <- lmer(y ~ x1i + x2i * x3i + (x1i|j), dat)
summary(mod1)

# make data missing
dat <-
  dat |> 
  mutate(
    # y: MNAR
    y = ifelse((y > quantile(y, .7)) & (runif(n1*n2) > .2), NA, y), 
    # x1i: MAR, conditional on x2i
    x1i = ifelse((x2i > quantile(x2i, .7)) & (runif(n1*n2) > .5), NA, x1i),
    # x2i: MCAR
    x2i = ifelse((runif(n1*n2) > .9), NA, x2i)
  )

# fit model with casewise deletion
mod2 <- lmer(y ~ x1i + x2i * x3i + (x1i|j), dat)
summary(mod2)

# write.csv(dat, "04_multilevel.csv", row.names = F)
